==> huaweicloudsdkelb-3.0.18b0-py3-none-any.whl: huaweicloudsdkelb/v2/model/list_healthmonitors_response.py <==
# coding: utf-8

import pprint
import re

import six


from huaweicloudsdkcore.sdk_response import SdkResponse


class ListHealthmonitorsResponse(SdkResponse):


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'healthmonitors': 'list[HealthmonitorV2Resp]'
    }

    attribute_map = {
        'healthmonitors': 'healthmonitors'
    }

    def __init__(self, healthmonitors=None):
        """ListHealthmonitorsResponse - a model defined in huaweicloud sdk"""
        
        super().__init__()

        self._healthmonitors = None
        self.discriminator = None

        if healthmonitors is not None:
            self.healthmonitors = healthmonitors

    @property
    def healthmonitors(self):
        """Gets the healthmonitors of this ListHealthmonitorsResponse.

        健康检查对象的列表

        :return: The healthmonitors of this ListHealthmonitorsResponse.
        :rtype: list[HealthmonitorV2Resp]
        """
        return self._healthmonitors

    @healthmonitors.setter
    def healthmonitors(self, healthmonitors):
        """Sets the healthmonitors of this ListHealthmonitorsResponse.

        健康检查对象的列表

        :param healthmonitors: The healthmonitors of this ListHealthmonitorsResponse.
        :type: list[HealthmonitorV2Resp]
        """
        self._healthmonitors = healthmonitors

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListHealthmonitorsResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkelb-3.0.23b0-py3-none-any.whl: huaweicloudsdkelb/v2/model/list_healthmonitors_response.py <==
# coding: utf-8

import pprint
import re

import six


from huaweicloudsdkcore.sdk_response import SdkResponse


class ListHealthmonitorsResponse(SdkResponse):


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'healthmonitors': 'list[HealthmonitorResp]'
    }

    attribute_map = {
        'healthmonitors': 'healthmonitors'
    }

    def __init__(self, healthmonitors=None):
        """ListHealthmonitorsResponse - a model defined in huaweicloud sdk"""
        
        super().__init__()

        self._healthmonitors = None
        self.discriminator = None

        if healthmonitors is not None:
            self.healthmonitors = healthmonitors

    @property
    def healthmonitors(self):
        """Gets the healthmonitors of this ListHealthmonitorsResponse.

        健康检查对象的列表

        :return: The healthmonitors of this ListHealthmonitorsResponse.
        :rtype: list[HealthmonitorResp]
        """
        return self._healthmonitors

    @healthmonitors.setter
    def healthmonitors(self, healthmonitors):
        """Sets the healthmonitors of this ListHealthmonitorsResponse.

        健康检查对象的列表

        :param healthmonitors: The healthmonitors of this ListHealthmonitorsResponse.
        :type: list[HealthmonitorResp]
        """
        self._healthmonitors = healthmonitors

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListHealthmonitorsResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
